@@ -1,6 +1,6 @@
 #include "messagebasictypes.h"
 #include "messagecomplextypes.h"
-#include "messagecontainertypes.h"
+#include "messagestlcontainertypes.h"
 #include <iostream>
 
 using namespace std;
@@ -81,13 +81,58 @@ int main()
     }
     pushFront(message,uintlist);
   }
-  // pop
+
+  {
+    vector <uint8> uintvector;
+    for (int i=0; i<10; i++)
+    {
+      uintvector.push_back(uint8(i));
+    }
+    pushFront(message,uintvector);
+  }
+
+  {
+    // nested serialization
+    list < vector < string > > vslist;
+    {
+      vector <string> vs1;
+      vs1.push_back("a1");
+      vs1.push_back("b1");
+      vslist.push_back(vs1);
+
+      vector <string> vs2;
+      vs2.push_back("a2");
+      vs2.push_back("b2");
+      vslist.push_back(vs2);
+    }
+    pushFront(message,vslist);
+  }
+
+
+// pop
+
+  {
+    // nested serialization
+    list < vector < string > > vslist;
+    popFront(message,vslist);
+  }
+
+  {
+    vector <uint8> uintvector;
+    popFront(message,uintvector);
+
+    std::vector<uint8>::const_iterator it;
+    for (it=uintvector.begin(); it!=uintvector.end(); it++)
+    {
+      cout << "uintvector " << int(*it) << endl;
+    }
+  }
 
   {
     list <uint8> uintlist;
     popFront(message,uintlist);
 
-    std::list<uint8>::iterator it;
+    std::list<uint8>::const_iterator it;
     for (it=uintlist.begin(); it!=uintlist.end(); it++)
     {
       cout << "unitlist " << int(*it) << endl;
