@@ -1,7 +1,7 @@
 #ifndef _tcpmessageserver_h
 #define _tcpmessageserver_h
 
-#include <asio.hpp>
+#include <boost/asio.hpp>
 #include <string>
 #include <boost/noncopyable.hpp>
 #include "tcpmessageserverconnection.h"
@@ -10,12 +10,12 @@
 class TCPMessageServer : private boost::noncopyable
 {
 private:
-  asio::io_service & ioservice;
-  asio::ip::tcp::acceptor acceptor;
+  boost::asio::io_service & ioservice;
+  boost::asio::ip::tcp::acceptor acceptor;
 
   ServerConnectorFactoryBase & serverConnectorFactoryBase;
 
-  void handleAccept(const asio::error_code& e);
+  void handleAccept(const boost::system::error_code& e);
   void handleStop();
 
   TCPMessageServerConnectionManager tcpMessageServerConnectionManager;
@@ -23,7 +23,7 @@ private:
   connection_ptr newConnection;
 
 public:
-  explicit TCPMessageServer(asio::io_service& io_service, const asio::ip::tcp::endpoint & endpoint, ServerConnectorFactoryBase & serverConnectorFactoryBase);
+  explicit TCPMessageServer(boost::asio::io_service& io_service, const boost::asio::ip::tcp::endpoint & endpoint, ServerConnectorFactoryBase & serverConnectorFactoryBase);
 
   void run();
 
