@@ -7,7 +7,7 @@
 using namespace std;
 
 
-TCPMessageServerConnection::TCPMessageServerConnection(asio::io_service& io_service,
+TCPMessageServerConnection::TCPMessageServerConnection(boost::asio::io_service& io_service,
     TCPMessageServerConnectionManager& manager, ServerConnectorFactoryBase & serverConnectorFactoryBase)
   : socket_(io_service), tcpMessageServerConnectionManager(manager), serverConnectorFactoryBase(serverConnectorFactoryBase)
 {
@@ -15,7 +15,7 @@ TCPMessageServerConnection::TCPMessageServerConnection(asio::io_service& io_serv
 }
 
 
-asio::ip::tcp::socket& TCPMessageServerConnection::socket()
+boost::asio::ip::tcp::socket& TCPMessageServerConnection::socket()
 {
   return socket_;
 }
@@ -28,10 +28,10 @@ void TCPMessageServerConnection::start()
   serverConnectorBasePtr->sendMessageSignal.connect(boost::bind(&TCPMessageServerConnection::queueAndSendMessageSlot, this, _1));  // FIXME: managed signal slot for clean shutdown
   messageSignal.connect(boost::bind(&ServerConnectorBase::receiveMessageSlot, serverConnectorBasePtr, _1));  // FIXME: managed signal slot for clean shutdown
 
-  asio::async_read(socket_,
-                   asio::buffer(data, sizeof(uint32)),
-                   asio::transfer_at_least(sizeof(uint32)),
-                   boost::bind(&TCPMessageServerConnection::handleReadMessageSize, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+  boost::asio::async_read(socket_,
+                          boost::asio::buffer(data, sizeof(uint32)),
+                          boost::asio::transfer_at_least(sizeof(uint32)),
+                          boost::bind(&TCPMessageServerConnection::handleReadMessageSize, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
 }
 
 
@@ -41,7 +41,7 @@ void TCPMessageServerConnection::stop()
 }
 
 
-void TCPMessageServerConnection::handleReadMessageSize(const asio::error_code& err, size_t length)
+void TCPMessageServerConnection::handleReadMessageSize(const boost::system::error_code& err, size_t length)
 {
   if (!err)
   {
@@ -51,19 +51,19 @@ void TCPMessageServerConnection::handleReadMessageSize(const asio::error_code& e
     Msg::popFrontuint32(sizeMessage, messageSizeTmp);
     messageSize=messageSizeTmp;
 
-    asio::async_read(socket_,
-                     asio::buffer(data, messageSize),
-                     asio::transfer_at_least(messageSize),
-                     boost::bind(&TCPMessageServerConnection::handleReadMessage, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+    boost::asio::async_read(socket_,
+                            boost::asio::buffer(data, messageSize),
+                            boost::asio::transfer_at_least(messageSize),
+                            boost::bind(&TCPMessageServerConnection::handleReadMessage, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
   }
-  else if (err != asio::error::operation_aborted)
+  else if (err != boost::asio::error::operation_aborted)
   {
     tcpMessageServerConnectionManager.stop(shared_from_this());
   }
 }
 
 
-void TCPMessageServerConnection::handleReadMessage(const asio::error_code& err, size_t length)
+void TCPMessageServerConnection::handleReadMessage(const boost::system::error_code& err, size_t length)
 {
   if (!err)
   {
@@ -77,12 +77,12 @@ void TCPMessageServerConnection::handleReadMessage(const asio::error_code& err,
 //    queueAndSendMessageSlot(returnMessage); // FIXME
 
     // read next size
-    asio::async_read(socket_,
-                     asio::buffer(data, sizeof(uint32)),
-                     asio::transfer_at_least(sizeof(uint32)),
-                     boost::bind(&TCPMessageServerConnection::handleReadMessageSize, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+    boost::asio::async_read(socket_,
+                            boost::asio::buffer(data, sizeof(uint32)),
+                            boost::asio::transfer_at_least(sizeof(uint32)),
+                            boost::bind(&TCPMessageServerConnection::handleReadMessageSize, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
   }
-  else if (err != asio::error::operation_aborted)
+  else if (err != boost::asio::error::operation_aborted)
   {
     tcpMessageServerConnectionManager.stop(shared_from_this());
   }
@@ -110,13 +110,13 @@ void TCPMessageServerConnection::startNewTransmission()
   {
     Message & message=sendQueue.front();
     sendQueueCurrentlySending=true;
-    asio::async_write(socket_,asio::buffer(message.getDataPtr(), message.size()),
-                      boost::bind(&TCPMessageServerConnection::handleWriteMessage, this, asio::placeholders::error));
+    boost::asio::async_write(socket_,boost::asio::buffer(message.getDataPtr(), message.size()),
+                             boost::bind(&TCPMessageServerConnection::handleWriteMessage, this, boost::asio::placeholders::error));
   }
 }
 
 
-void TCPMessageServerConnection::handleWriteMessage(const asio::error_code& err)
+void TCPMessageServerConnection::handleWriteMessage(const boost::system::error_code& err)
 {
   // cout << "UDPMessageClient::handleSendTo" << endl;
   // cout << "sendQueue.front().size()=" << sendQueue.front().size() << endl;
