@@ -2,7 +2,7 @@
 #define _tcpmessageserverconnection_h
 
 #include <set>
-#include <asio.hpp>
+#include <boost/asio.hpp>
 #include <boost/array.hpp>
 #include <boost/noncopyable.hpp>
 #include <boost/shared_ptr.hpp>
@@ -18,7 +18,7 @@ class TCPMessageServerConnection
   private boost::noncopyable
 {
 private:
-  asio::ip::tcp::socket socket_;
+  boost::asio::ip::tcp::socket socket_;
   TCPMessageServerConnectionManager & tcpMessageServerConnectionManager;
   boost::signal<void (Message & message)> messageSignal;
 
@@ -29,19 +29,19 @@ private:
   unsigned long messageSize;
   char data[maxMessageIOSize];
 
-  void handleReadMessageSize(const asio::error_code& err, size_t length);
-  void handleReadMessage(const asio::error_code& err, size_t length);
+  void handleReadMessageSize(const boost::system::error_code& err, size_t length);
+  void handleReadMessage(const boost::system::error_code& err, size_t length);
 
   void queueAndSendMessageSlot(Message & message);
   std::list<Message>  sendQueue;
   bool sendQueueCurrentlySending;
   void startNewTransmission();
-  void handleWriteMessage(const asio::error_code& err);
+  void handleWriteMessage(const boost::system::error_code& err);
 
 public:
-  explicit TCPMessageServerConnection(asio::io_service& io_service, TCPMessageServerConnectionManager& manager, ServerConnectorFactoryBase & serverConnectorFactoryBase);
+  explicit TCPMessageServerConnection(boost::asio::io_service& io_service, TCPMessageServerConnectionManager& manager, ServerConnectorFactoryBase & serverConnectorFactoryBase);
 
-  asio::ip::tcp::socket& socket();
+  boost::asio::ip::tcp::socket& socket();
 
   void start();
   void stop();
