@@ -4,11 +4,11 @@
 using namespace std;
 
 
-UDPMessageClient::UDPMessageClient(asio::io_service& io_service, const char * host, const char * port) : ioservice(io_service), resolver(ioservice), socket(ioservice)
+UDPMessageClient::UDPMessageClient(boost::asio::io_service& io_service, const char * host, const char * port) : ioservice(io_service), resolver(ioservice), socket(ioservice)
 {
-  asio::ip::udp::resolver::query query(host, port);
+  boost::asio::ip::udp::resolver::query query(host, port);
   resolver.async_resolve(query,
-                         boost::bind(&UDPMessageClient::handleResolve, this, asio::placeholders::error, asio::placeholders::iterator));
+                         boost::bind(&UDPMessageClient::handleResolve, this, boost::asio::placeholders::error, boost::asio::placeholders::iterator));
   stopAfterOneReceivedMessage=false;
   sendQueueCurrentlySending=false;
 }
@@ -19,7 +19,7 @@ UDPMessageClient::~UDPMessageClient()
 }
 
 
-void UDPMessageClient::handleResolve(const asio::error_code& err, asio::ip::udp::resolver::iterator endpointIterator)
+void UDPMessageClient::handleResolve(const boost::system::error_code& err, boost::asio::ip::udp::resolver::iterator endpointIterator)
 {
   // cout << "UDPMessageClient::handleResolve" << endl;
   if (err)
@@ -30,22 +30,22 @@ void UDPMessageClient::handleResolve(const asio::error_code& err, asio::ip::udp:
   {
     remoteEndpoint=*endpointIterator;
 
-    asio::ip::udp::endpoint localEndpoint(remoteEndpoint.protocol(), 0);
+    boost::asio::ip::udp::endpoint localEndpoint(remoteEndpoint.protocol(), 0);
     socket.open(localEndpoint.protocol());
     if (localEndpoint.address().is_v6())
     {
-      socket.set_option(asio::ip::v6_only(true));
+      socket.set_option(boost::asio::ip::v6_only(true));
     }
     socket.bind(localEndpoint);
 
-    socket.async_receive_from(asio::buffer(data, maxMessageIOSize), remoteEndpoint,
-                              boost::bind(&UDPMessageClient::handleReceiveFrom, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+    socket.async_receive_from(boost::asio::buffer(data, maxMessageIOSize), remoteEndpoint,
+                              boost::bind(&UDPMessageClient::handleReceiveFrom, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
     connectionReadySignal();
   }
 }
 
 
-void UDPMessageClient::handleReceiveFrom(const asio::error_code& err, size_t length)
+void UDPMessageClient::handleReceiveFrom(const boost::system::error_code& err, size_t length)
 {
   //cout << "UDPMessageClient::handle_receive_from" << endl;
   if (err)
@@ -59,8 +59,8 @@ void UDPMessageClient::handleReceiveFrom(const asio::error_code& err, size_t len
 
     if (false==stopAfterOneReceivedMessage)
     {
-      socket.async_receive_from(asio::buffer(data, maxMessageIOSize), remoteEndpoint,
-                                boost::bind(&UDPMessageClient::handleReceiveFrom, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+      socket.async_receive_from(boost::asio::buffer(data, maxMessageIOSize), remoteEndpoint,
+                                boost::bind(&UDPMessageClient::handleReceiveFrom, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
     }
   }
 }
@@ -88,13 +88,13 @@ void UDPMessageClient::startNewTransmission()
   {
     Message message=sendQueue.front();
     sendQueueCurrentlySending=true;
-    socket.async_send_to(asio::buffer(message.getDataPtr(), message.size()), remoteEndpoint,
-                         boost::bind(&UDPMessageClient::handleSendTo, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+    socket.async_send_to(boost::asio::buffer(message.getDataPtr(), message.size()), remoteEndpoint,
+                         boost::bind(&UDPMessageClient::handleSendTo, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
   }
 }
 
 
-void UDPMessageClient::handleSendTo(const asio::error_code& err, size_t length)
+void UDPMessageClient::handleSendTo(const boost::system::error_code& err, size_t length)
 {
   // cout << "UDPMessageClient::handleSendTo" << endl;
   // cout << "sendQueue.front().size()=" << sendQueue.front().size() << endl;
