@@ -3,16 +3,16 @@
 
 
 #include "protocoltimer.h"
-#include <asio.hpp>
+#include <boost/asio.hpp>
 
 
 class ProtocolIOAsio : public ProtocolIO
 {
 private:
-  asio::io_service & ioservice;
+  boost::asio::io_service & ioservice;
 
 public:
-  ProtocolIOAsio(asio::io_service & ioservice);
+  ProtocolIOAsio(boost::asio::io_service & ioservice);
 
   boost::posix_time::ptime currentTimeUTC();
   TheTimerObjectBase * getTimer();
@@ -22,15 +22,15 @@ public:
 class TheTimerObjectAsio : public TheTimerObjectBase
 {
 private:
-  asio::io_service & ioservice;
+  boost::asio::io_service & ioservice;
 
   bool timerActive;
-  asio::deadline_timer timer;
+  boost::asio::deadline_timer timer;
 
-  void timerExpiredEvent(const asio::error_code& err);
+  void timerExpiredEvent(const boost::system::error_code& err);
 
 public:
-  TheTimerObjectAsio(asio::io_service & ioservice);
+  TheTimerObjectAsio(boost::asio::io_service & ioservice);
   ~TheTimerObjectAsio();
 
   void startAlarmAt(const boost::posix_time::ptime & time, TimerEventHandlerBase * handler);
