@@ -4,7 +4,7 @@
 
 #include <list>
 #include <string>
-#include <asio.hpp>
+#include <boost/asio.hpp>
 #ifdef HAVE_CURSES_H
 #include <curses.h>
 #endif
@@ -18,7 +18,7 @@
 class SinfoCurses
 {
 private:
-  asio::io_service & ioservice;
+  boost::asio::io_service & ioservice;
   SinfoViewConfig & config;
   SinfoData & sinfoData;
   std::list < Wsinfo > & wsinfoList; // located within sinfoData - to minimize code change
@@ -34,8 +34,8 @@ private:
   void printInteractiveOneHost(int maxy, int maxx, int & y, int & x, bool colormode, const Wsinfo & wsinfo, float speedMin, float speedMax);
 
   // keyboard handling   stdin => curses
-  void handle_read(const asio::error_code& e, std::size_t bytes_transferred); // Handle completion of a read operation.
-  asio::posix::stream_descriptor instream;                                    // stream on stdin
+  void handle_read(const boost::system::error_code& e, std::size_t bytes_transferred); // Handle completion of a read operation.
+  boost::asio::posix::stream_descriptor instream;                                    // stream on stdin
 
   void keyCodeEvent(int key);
   void wsinfoListChangedSlot();
@@ -45,7 +45,7 @@ private:
 
 
 public:
-  SinfoCurses(asio::io_service& io_service, SinfoViewConfig & _config, SinfoData & _sinfoData);
+  SinfoCurses(boost::asio::io_service& io_service, SinfoViewConfig & _config, SinfoData & _sinfoData);
 
   void printInit();
 };
