@@ -39,3 +39,20 @@ void SinfoData::calcSpeedInfo(long & cpuCount, float & speedSum, float & speedUs
                  * it->cpuinfo.cpus * it->cpuinfo.speedmhz;
   }
 }
+
+
+long SinfoData::getProcinfoListMax()
+{
+  long procinfoListMax=0;
+  for (list < Wsinfo > ::iterator it = wsinfoList.begin();
+       it != wsinfoList.end();
+       it++)
+  {
+    if (it->procinfoList.size()>procinfoListMax)
+    {
+      procinfoListMax=it->procinfoList.size();
+    }
+  }
+  return procinfoListMax;
+}
+
