@@ -70,7 +70,7 @@ void SinfoHTML::printHTMLOneHost(int maxx, const Wsinfo & wsinfo, float speedMin
     cout << "<SPAN class=\"hostname\">";
   cout << wsinfo.name;
   cout << "</SPAN>";
-  for (unsigned int i = 0; i < HOSTNAMEMAXSIZE - wsinfo.name.size(); i++)
+  for (unsigned int i = wsinfo.name.size(); i < HOSTNAMEMAXSIZE; i++)
     cout << "&nbsp;";
 
   //  if (d_total != 0)
