@@ -4,11 +4,11 @@
 
 #include <boost/signal.hpp>
 #include "sinfodata.h"
-#include "message.h"
 #include "protocoltimer.h"
+#include "sinfo.idlx.client.h"
 
 
-class SinfoRequester
+class SinfoRequester : public SinfoClientRequest, SinfoClientReply
 {
 private:
   SinfoData & sinfoData;
@@ -18,12 +18,18 @@ private:
 
   void requestUpdate();
 
+
   ProtocolTimer requestUpdateTimer;
   void requestUpdateTimerExpiredEvent();
 
   ProtocolTimer periodicRequestTimer;
   void periodicRequestTimerExpiredEvent();
 
+  virtual void getSinfoListReply(const std::list< Wsinfo > & wsinfoList);
+  virtual void getFilteredSinfoListReply(const std::list< Wsinfo > & wsinfoList);
+
+  void sinfoClientRequestMessageSlot(Message & message);
+
 public:
   unsigned long delay_millisec;
   unsigned long timeout_millisec;
@@ -33,9 +39,10 @@ public:
   SinfoRequester(ProtocolIO & protocolIO, SinfoData & _sinfoData);
 
   void connectionReadySlot();
-  boost::signal<void (Message & message)> queueAndSendMessageSignal;
   void receivedMessageSlot(Message & returnMessage);
   boost::signal<void ()> timeoutSignal;
+
+  boost::signal<void (Message & message)> queueAndSendMessageSignal;
 };
 
 
