@@ -14,8 +14,8 @@ public:
   enum DispScale { log, lin, full };
 
   bool quiet;
-  char * username;
-  char * hostname;
+  std::string username;
+  std::string hostname;
   int listtop;
   bool systeminfo;
   DispScale dispScale;
