@@ -1,7 +1,7 @@
 #ifndef _broadcastreceiver_h
 #define _broadcastreceiver_h
 
-#include <asio.hpp>
+#include <boost/asio.hpp>
 #include "message.h"
 #include "sinfo.h"
 
@@ -11,10 +11,10 @@ class BroadcastReceiver
 private:
   enum { max_length = 65535 }; // maximum UDP packet size
   char data[max_length];
-  asio::ip::udp::endpoint sender_endpoint;
+  boost::asio::ip::udp::endpoint sender_endpoint;
 
-  asio::io_service & ioservice;
-  asio::ip::udp::socket sock;
+  boost::asio::io_service & ioservice;
+  boost::asio::ip::udp::socket sock;
 
   bool & restartCounterEventFlag;
   std::list < Wsinfo > & wsinfoList;
@@ -22,8 +22,8 @@ private:
   void  receiveMessage(std::string inetaddrString, unsigned long inetaddrHostByteOrder, Message & message);
 
 public:
-  BroadcastReceiver(asio::io_service& io_service, bool & _restartCounterEventFlag, std::list < Wsinfo > & _wsinfoList);
-  void handle_receive_from(const asio::error_code& err, size_t length);
+  BroadcastReceiver(boost::asio::io_service& io_service, bool & _restartCounterEventFlag, std::list < Wsinfo > & _wsinfoList);
+  void handle_receive_from(const boost::system::error_code& err, size_t length);
 };
 
 
