@@ -10,7 +10,7 @@ const unsigned long deleteoldTimer = 300;
 
 
 
-CleanupList::CleanupList(asio::io_service& io_service, std::list < Wsinfo > & _wsinfoList):ioservice(io_service), timer(io_service), wsinfoList(_wsinfoList)
+CleanupList::CleanupList(boost::asio::io_service& io_service, std::list < Wsinfo > & _wsinfoList):ioservice(io_service), timer(io_service), wsinfoList(_wsinfoList)
 {
   timer.expires_from_now(boost::posix_time::seconds(deleteoldTimer));
   timer.async_wait(boost::bind(&CleanupList::handle_timeout, this));
