@@ -2,15 +2,15 @@
 #define _cleanuplist_h
 
 
-#include <asio.hpp>
+#include <boost/asio.hpp>
 #include "sinfo.h"
 
 
 class CleanupList
 {
 private:
-  asio::io_service & ioservice;
-  asio::deadline_timer timer;
+  boost::asio::io_service & ioservice;
+  boost::asio::deadline_timer timer;
 
   std::list < Wsinfo > & wsinfoList;
 
@@ -19,7 +19,7 @@ private:
 
 
 public:
-  CleanupList(asio::io_service& io_service, std::list < Wsinfo > & _wsinfoList);
+  CleanupList(boost::asio::io_service& io_service, std::list < Wsinfo > & _wsinfoList);
 
 };
 
