@@ -2,7 +2,7 @@
 #define _measureserver_h
 
 
-#include <asio.hpp>
+#include <boost/asio.hpp>
 #include "cpustatmeter.h"
 #include "netloadmeter.h"
 #include "diskloadmeter.h"
@@ -13,8 +13,8 @@
 class MeasureServer
 {
 private:
-  asio::io_service & ioservice;
-  asio::deadline_timer timer;
+  boost::asio::io_service & ioservice;
+  boost::asio::deadline_timer timer;
 
   unsigned long timeCounter;
 
@@ -35,7 +35,7 @@ private:
 
 
 public:
-  MeasureServer(asio::io_service& io_service, const std::string & networkcard, const std::string & _marker, bool cmdlinemode, std::list < std::string > ignoreList, long listtop);
+  MeasureServer(boost::asio::io_service& io_service, const std::string & networkcard, const std::string & _marker, bool cmdlinemode, std::list < std::string > ignoreList, long listtop);
   ~MeasureServer();
 
   void timerEvent();
